predict_bbase_os <-
function(object, newx) {
	B <- predict(object, newx = newx)
	B
}
